
# This file is automatically generated by setup.py, So don't edit it. :)
VERSION_INFO = {
    'final': True,
    'version': '1.5.11.post2',
    'branch_nick': '(no',
    'revision_id': '6d6218c18af4d4fdc248a8df6a786d8712796987',
    'revno': 3947
}
